@@ -4,9 +4,9 @@ from .VueWidget import VueWidget
 
 class Html(VueWidget):
 
-    _model_name = Unicode('HtmlModel').tag(sync=True)
+    _model_name = Unicode("HtmlModel").tag(sync=True)
 
     tag = Unicode().tag(sync=True)
 
 
-__all__ = ['Html']
+__all__ = ["Html"]
